## ----setup, include=FALSE------------------------------------------------
source("_setup.R")

## ---- echo = FALSE, include=FALSE----------------------------------------

require(lattice)
require(MASS)
require(effects)
require(knitr)

dados <- read.csv('../data-raw/Baseauto2.csv', header=TRUE, sep=',', dec = ',')

options(scipen = 3) ### Era zero.

##### Preparando os dados.
names(dados) <- c('Bonus','Tipo','Estado','Idade','Sexo','Civil','Valor','Exposicao','Sinistros')
dados <- dados[,c('Idade','Sexo','Valor','Exposicao','Sinistros')]
dados <- dados[which(dados$Valor != 0),]
dados$lexpo <- log(dados$Exposicao)
dados$Valor <- dados$Valor/1000


## ------------------------------------------------------------------------
head(dados, 10) ### Dez primeiras linhas da base.
str(dados)

## ------------------------------------------------------------------------
table(dados$Sinistros) ### Distribuição do números de sinistros.
taxageral <- sum(dados$Sinistros)/sum(dados$Exposicao); taxageral ### Taxa de sinistros na amostra.

tab <- aggregate(cbind(Exposicao, Sinistros) ~ Sexo, data = dados, sum)
taxa <- with(tab, Sinistros/Exposicao)
tab <- cbind(tab, taxa)
### Distribuição do número de sinistros por sexo.
kable(tab, align = 'c', caption = '**Taxa de sinistros segundo Sexo**')

dados$idadecat <- cut(dados$Idade, breaks=c(18,30,60, 92), include.lowest = T)
tab <- aggregate(cbind(Exposicao, Sinistros) ~ idadecat, data = dados, sum)
taxa <- with(tab, Sinistros/Exposicao)
tab <- cbind(tab, taxa)
### Distribuição do número de sinistros por sexo.
kable(tab, align = 'c', caption = '**Taxa de sinistros segundo Idade**')

tabidsex <- aggregate(cbind(Exposicao, Sinistros) ~ Sexo + idadecat, data = dados, sum)
taxa <- with(tabidsex, Sinistros/Exposicao)
tabidsex <- cbind(tabidsex, taxa)
### Distribuição do número de sinistros por idade e sexo.
kable(tabidsex, align = 'c', caption = '**Taxa de sinistros segundo Sexo e Idade**')


## ------------------------------------------------------------------------
dados <- na.omit(dados)
ajusteps <- glm(Sinistros ~ Sexo+Idade+I(Idade**2)+Valor+offset(log(Exposicao)), data = dados, family=poisson)
summary(ajusteps)

### Estimação do parâmetro de dispersão. 

X2 <- sum(resid(ajusteps,type='pearson')**2)
phichap <- X2/ajusteps$df.residual
phichap ### Indicador de superdispersão.

## ---- echo = FALSE-------------------------------------------------------
envelope=function(modelo){
  dados=na.omit(modelo$data)
  nsim=100
  n=modelo$df.null+1
  r1=sort(rstandard(modelo,type='deviance'))
  m1=matrix(0,nrow=n,ncol=nsim)
  a2=simulate(modelo,nsim=nsim)
  
  for (i in 1:nsim){
    dados$y=a2[,i]
    aj=update(modelo,y~.,data=dados)
    m1[,i]=sort(rstandard(aj,type='deviance'))}
  
  li=apply(m1,1,quantile,0.025)
  m=apply(m1,1,quantile,0.5)
  ls=apply(m1,1,quantile,0.975)
  
  quantis=qnorm((1:n-0.5)/n)
  
  plot(rep(quantis,2),c(li,ls),type='n',xlab='Percentil da N(0,1)',ylab='Resíduos')
  title('Gráfico Normal de Probabilidades')
  lines(quantis,li,type='l')
  lines(quantis,m,type='l',lty=2)
  lines(quantis,ls,type='l')
  points(quantis,r1,pch=16,cex=0.75)
}

## ------------------------------------------------------------------------
##### Diagnóstico do modelo - gráficos.
par(mfrow=c(2,2))
plot(ajusteps)

par(mfrow=c(1,1))
envelope(ajusteps)

## ------------------------------------------------------------------------
ajusteps2 <- glm(Sinistros ~ Sexo + Idade +I(Idade**2) + Valor + log(Exposicao), data = dados, family=poisson)
summary(ajusteps2)
anova(ajusteps, ajusteps2, test = 'Chisq')

## ------------------------------------------------------------------------
ajustenb2 <- glm.nb(Sinistros ~ Sexo+Idade+I(Idade**2)+Valor+log(Exposicao),data= dados)
summary(ajustenb2) 


## ------------------------------------------------------------------------
##### Diagnóstico do modelo - gráficos.
par(mfrow=c(2,2))
plot(ajustenb2)

## ---- echo = FALSE-------------------------------------------------------
dadosnb3 <- dados[,c('Sexo','Idade','Valor','Exposicao','Sinistros')]
dadosnb3$lexpo <- log(dados$Exposicao)
ajustenb2 <- glm.nb(Sinistros ~ Sexo+Idade+I(Idade**2)+Valor+lexpo,data= dadosnb3)
envelope=function(modelo){
  dados=na.omit(dadosnb3)
  nsim=100
  n=modelo$df.null+1
  r1=sort(rstandard(modelo,type='deviance'))
  m1=matrix(0,nrow=n,ncol=nsim)
  a2=simulate(modelo,nsim=nsim)
  
  for (i in 1:nsim){
    dados$y=a2[,i]
    aj=update(modelo,y~.,data=dados)
    m1[,i]=sort(rstandard(aj,type='deviance'))}
  
  li=apply(m1,1,quantile,0.025)
  m=apply(m1,1,quantile,0.5)
  ls=apply(m1,1,quantile,0.975)
  
  quantis=qnorm((1:n-0.5)/n)
  
  plot(rep(quantis,2),c(li,ls),type='n',xlab='Percentil da N(0,1)',ylab='Resíduos')
  title('Gráfico Normal de Probabilidades')
  lines(quantis,li,type='l')
  lines(quantis,m,type='l',lty=2)
  lines(quantis,ls,type='l')
  points(quantis,r1,pch=16,cex=0.75)
}

## ------------------------------------------------------------------------
par(mfrow=c(1,1))
envelope(ajustenb2)

## ------------------------------------------------------------------------
intervalos <- confint(ajustenb2)
estimat <- cbind(ajustenb2$coefficients, intervalos)
colnames(estimat)[1] <- 'Estimativa pontual'

### Quadro de estimativas
kable(round(estimat, 5), align = 'c', caption = '**Estimativas pontuais e intervalos de confiança - Modelo Binomial Negativo**')

## ---- echo = FALSE-------------------------------------------------------


## ------------------------------------------------------------------------

efeitos <- allEffects(ajustenb2, given.values=c(lexpo=0))
trellis.par.set(list(axis.text = list(cex = 1.2))) 

plot(efeitos[[2]], type='response',main=list(
    label="Taxa de sinistros vs. Idade",
    cex=1.5),
    xlab=list(
        label="Idade (anos)",
        cex=1.5),
    ylab=list(
        label="Taxa de sinistros",
        cex=1.5))

plot(efeitos[[1]], type='response',main=list(
    label="Taxa de sinistros vs. Sexo",
    cex=1.5),
    xlab=list(
        label="Sexo",
        cex=1.5),
    ylab=list(
        label="Taxa de  sinistros",
        cex=1.5))

plot(efeitos[[4]], type='response',main=list(
    label="Taxa de sinistros vs. Valor do automóvel",
    cex=1.5),
    xlab=list(
        label="Valor (x1000 reais)",
        cex=1.5),
    ylab=list(
        label="Taxa de sinistros",
        cex=1.5))


## ---- echo = FALSE, include=F--------------------------------------------

## Frequências ajustadas pelas duas distribuições, com e sem covariaveis.

### Poisson sem ajuste de covariáveis.
n <- nrow(dados)
mediasin <- mean(dados$Sinistros)
freqps <- round(n*dpois(0:10,mediasin))


### Poisson com covariaveis
pred1 <- predict(ajusteps2,type='response')
intervalo <- 0:10
matprob <- matrix(0, nrow=nrow(dados), ncol=length(intervalo))
probpois <- function(interv, taxa)
    dpois(intervalo,taxa)
for(i in 1:nrow(dados))
    matprob[i,] <- probpois(interv = intervalo, taxa = pred1[i])
pbarra <- colMeans(matprob)
freqpsaj <- round(n*pbarra)



### Binomial negativa sem covariaveis.
ajustenb <- glm.nb(Sinistros ~ 1,data=dados)

media <- exp(coefficients(ajustenb))
shape <- ajustenb$theta
freqbn <- round(n*dnbinom(0:10, mu = media, size = shape))


### Binomial negativa com covariaveis
pred2 <- predict(ajustenb2,type='response')

intervalo <- 0:10
matprob <- matrix(0,nrow=nrow(dados),ncol=length(intervalo))
probnb <- function(interv, media, shape)
    dnbinom(intervalo, mu = media, size = shape)
for(i in 1:nrow(dados))
    matprob[i,] <- probnb(interv = intervalo, media = pred2[i], shape = ajustenb2$theta)
pbarra <- colMeans(matprob)
frebnaj <- round(n*pbarra)
ams <- c(table(dados$Sinistros), rep(0,5))
matfreq <- rbind(ams, freqps, freqpsaj, freqbn, frebnaj)
colnames(matfreq) <- 0:10
rownames(matfreq) <- c('Amostra', 'Poisson não ajustada por covariáveis', 'Poisson ajustada por covariáveis', 
                       'BN não ajustada por covariáveis', 'BN ajustada por covariáveis')

## ---- results = 'markup'-------------------------------------------------
kable(matfreq, format = "markdown", caption = "Frequências amostrais e frequências ajustadas para o número de sinistros")

